@@ -201,155 +201,155 @@ class dummy():
 ###################################################################
 # PUBLIC FUNCTIONS                                                #
 ###################################################################
-# xxx-replace
-## LAST MODIFIED : December 12, 2012
-## CREATED : December 12, 2012
-## AUTHOR : DRYX
-def get_fieldset(attributeDict):
-  """Create a ``fieldset`` HTML code block with legend
+# # xxx-replace
+# ## LAST MODIFIED : December 12, 2012
+# ## CREATED : December 12, 2012
+# ## AUTHOR : DRYX
+# def get_fieldset(attributeDict):
+#   """Create a ``fieldset`` HTML code block with legend
 
-  **Key Arguments:**
-    - ``attributeDict`` -- dictionary of the following keywords:
-      - ``htmlClass`` -- the html element class
-      - ``htmlId`` -- the html element id
-      - ``blockContent`` -- actual content to be placed in html code block
-      - ``jsEvents`` -- inline javascript event
-      - ``extraAttr`` -- extra incline css attributes and/or handles
-      - ``legend`` -- fieldset legend
+#   **Key Arguments:**
+#     - ``attributeDict`` -- dictionary of the following keywords:
+#       - ``htmlClass`` -- the html element class
+#       - ``htmlId`` -- the html element id
+#       - ``blockContent`` -- actual content to be placed in html code block
+#       - ``jsEvents`` -- inline javascript event
+#       - ``extraAttr`` -- extra incline css attributes and/or handles
+#       - ``legend`` -- fieldset legend
 
-  **Return:**
-    - ``block``
+#   **Return:**
+#     - ``block``
 
-  attributeDict template -- dict(htmlClass=___,
-                                  htmlId=___,
-                                  jsEvents=___,
-                                  extraAttr=___,
-                                  blockContent=___,
-                                  legend=___
-                                )
-  """
+#   attributeDict template -- dict(htmlClass=___,
+#                                   htmlId=___,
+#                                   jsEvents=___,
+#                                   extraAttr=___,
+#                                   blockContent=___,
+#                                   legend=___
+#                                 )
+#   """
+#   ################ > IMPORTS ################
+
+#   ################ > VARIABLE SETTINGS ######
+#   block = "<fieldset "  # THE HTML BLOCK
+#   d = attributeDict
+
+#   ################ >ACTION(S) ################
+#   ## SET THE ATTRIBUTES
+#   if d.has_key("htmlClass"):
+#     block += """class="%s" """ % (d["htmlClass"],)
+#   if d.has_key("htmlId"):
+#     block += """id="%s" """ % (d["htmlId"],)
+#   if d.has_key("jsEvents"):
+#     block += """%s """ % (d["jsEvents"],)
+#   if d.has_key("extraAttr"):
+#     block += """%s """ % (d["extraAttr"],)
+#   block += ">"
+
+#   if d["legend"]:
+#     block += "<legend>%s</legend>" % (d["legend"],)
+
+#   ## SET THE CONTENT
+#   if d.has_key("blockContent"):
+#     block += str(d["blockContent"])
+
+#   ## CLOSE THE BLOCK
+#   if d.has_key("htmlId"):
+#     block += "</fieldset><!--- /#%s --->" % (d["htmlId"],)
+#   else:
+#     block += "</fieldset>"
+
+#   return block
+
+# # xxx-replace
+# ## LAST MODIFIED : December 12, 2012
+# ## CREATED : December 12, 2012
+# ## AUTHOR : DRYX
+# def get_input_block(attributeDict):
+#   """The HTML5 input tag used mainly in forms
+
+#   **Key Arguments:**
+#     - ``attributeDict`` -- dictionary of the following keywords:
+#     - ``tag`` -- input, textarea
+#     - ``htmlClass`` -- the html element class
+#     - ``htmlId`` -- the html element id
+#     - ``blockContent`` -- actual content to be placed in html code block
+#     - ``jsEvents`` -- inline javascript event
+#     - ``extraAttr`` -- extra incline css attributes and/or handles
+#     - ``name`` -- an extra hook (much like "id")
+#     - ``type`` -- HTML input types = color, date, datetime, datetime-local, email, month, number, range, search, tel, time, url, week
+#     - ``placeholder`` -- text to be displayed by default in the input box
+#     - ``required`` -- make input required (boolean)
+#     - ``autofocus`` -- make this the auofocus element of the form (i.e. place cursor here)
+#     - ``maxlength`` -- maximum character length for the form
+#     - ``row`` -- number of rows for a *textarea* (i.e. height of the textbox)
+
+#   **Returns**
+#     - ``block`` -- the input HTML code block
+
+#   attributeDict template --
+#       dict(
+#             tag=___,
+#             htmlClass=___,
+#             htmlId=___,
+#             jsEvents=___,
+#             extraAttr=___,
+#             blockContent=___,
+#             name=___,
+#             type=___,
+#             placeholder=___,
+#             required=___,
+#             autofocus=___,
+#             maxlength=___,
+#             row=___,
+#             value=___
+#           )
+#   """
   ################ > IMPORTS ################
 
   ################ > VARIABLE SETTINGS ######
-  block = "<fieldset "  # THE HTML BLOCK
-  d = attributeDict
+  # d = attributeDict
 
-  ################ >ACTION(S) ################
-  ## SET THE ATTRIBUTES
-  if d.has_key("htmlClass"):
-    block += """class="%s" """ % (d["htmlClass"],)
-  if d.has_key("htmlId"):
-    block += """id="%s" """ % (d["htmlId"],)
-  if d.has_key("jsEvents"):
-    block += """%s """ % (d["jsEvents"],)
-  if d.has_key("extraAttr"):
-    block += """%s """ % (d["extraAttr"],)
-  block += ">"
+  # ################ >ACTION(S) ################
+  # if d.has_key("label"):
+  #   block = """<label>%s<label>\n<%s """ % (d["label"],d["tag"],)
+  # else:
+  #   block = """<%s """ % (d["tag"],)
 
-  if d["legend"]:
-    block += "<legend>%s</legend>" % (d["legend"],)
+  # if d.has_key("htmlClass"):
+  #   block += """class="%s" """ % (d["htmlClass"],)
+  # if d.has_key("htmlId"):
+  #   block += """id="%s" """ % (d["htmlId"],)
+  # if d.has_key("jsEvents"):
+  #   block += """%s """ % (d["jsEvents"],)
+  # if d.has_key("extraAttr"):
+  #   block += """%s """ % (d["extraAttr"],)
+  # if d.has_key("name"):
+  #   block += """name="%s" """ % (d["name"],)
+  # if d.has_key("type"):
+  #   block += """type="%s" """ % (d["type"],)
+  # if d.has_key("placeholder"):
+  #   block += """placeholder="%s" """ % (d["placeholder"],)
+  # if d.has_key("maxlength"):
+  #   block += """maxlength="%s" """ % (d["maxlength"],)
+  # if d.has_key("required") and d["required"]:
+  #   block += """required """
+  # if d.has_key("autofocus"):
+  #   block += """autofocus """
+  # if d.has_key("value"):
+  #   block += """value """
+  # block += ">"
 
-  ## SET THE CONTENT
-  if d.has_key("blockContent"):
-    block += str(d["blockContent"])
+  # ## SET THE CONTENT
+  # if d.has_key("blockContent"):
+  #   block += str(d["blockContent"])
+  # ## CLOSE THE BLOCK
+  # if d.has_key("htmlId"):
+  #   block += "</%s><!--- /#%s --->" % (d["tag"],d["htmlId"],)
+  # else:
+  #   block += "</%s>" % (d["tag"],)
 
-  ## CLOSE THE BLOCK
-  if d.has_key("htmlId"):
-    block += "</fieldset><!--- /#%s --->" % (d["htmlId"],)
-  else:
-    block += "</fieldset>"
-
-  return block
-
-# xxx-replace
-## LAST MODIFIED : December 12, 2012
-## CREATED : December 12, 2012
-## AUTHOR : DRYX
-def get_input_block(attributeDict):
-  """The HTML5 input tag used mainly in forms
-
-  **Key Arguments:**
-    - ``attributeDict`` -- dictionary of the following keywords:
-    - ``tag`` -- input, textarea
-    - ``htmlClass`` -- the html element class
-    - ``htmlId`` -- the html element id
-    - ``blockContent`` -- actual content to be placed in html code block
-    - ``jsEvents`` -- inline javascript event
-    - ``extraAttr`` -- extra incline css attributes and/or handles
-    - ``name`` -- an extra hook (much like "id")
-    - ``type`` -- HTML input types = color, date, datetime, datetime-local, email, month, number, range, search, tel, time, url, week
-    - ``placeholder`` -- text to be displayed by default in the input box
-    - ``required`` -- make input required (boolean)
-    - ``autofocus`` -- make this the auofocus element of the form (i.e. place cursor here)
-    - ``maxlength`` -- maximum character length for the form
-    - ``row`` -- number of rows for a *textarea* (i.e. height of the textbox)
-
-  **Returns**
-    - ``block`` -- the input HTML code block
-
-  attributeDict template --
-      dict(
-            tag=___,
-            htmlClass=___,
-            htmlId=___,
-            jsEvents=___,
-            extraAttr=___,
-            blockContent=___,
-            name=___,
-            type=___,
-            placeholder=___,
-            required=___,
-            autofocus=___,
-            maxlength=___,
-            row=___,
-            value=___
-          )
-  """
-  ################ > IMPORTS ################
-
-  ################ > VARIABLE SETTINGS ######
-  d = attributeDict
-
-  ################ >ACTION(S) ################
-  if d.has_key("label"):
-    block = """<label>%s<label>\n<%s """ % (d["label"],d["tag"],)
-  else:
-    block = """<%s """ % (d["tag"],)
-
-  if d.has_key("htmlClass"):
-    block += """class="%s" """ % (d["htmlClass"],)
-  if d.has_key("htmlId"):
-    block += """id="%s" """ % (d["htmlId"],)
-  if d.has_key("jsEvents"):
-    block += """%s """ % (d["jsEvents"],)
-  if d.has_key("extraAttr"):
-    block += """%s """ % (d["extraAttr"],)
-  if d.has_key("name"):
-    block += """name="%s" """ % (d["name"],)
-  if d.has_key("type"):
-    block += """type="%s" """ % (d["type"],)
-  if d.has_key("placeholder"):
-    block += """placeholder="%s" """ % (d["placeholder"],)
-  if d.has_key("maxlength"):
-    block += """maxlength="%s" """ % (d["maxlength"],)
-  if d.has_key("required") and d["required"]:
-    block += """required """
-  if d.has_key("autofocus"):
-    block += """autofocus """
-  if d.has_key("value"):
-    block += """value """
-  block += ">"
-
-  ## SET THE CONTENT
-  if d.has_key("blockContent"):
-    block += str(d["blockContent"])
-  ## CLOSE THE BLOCK
-  if d.has_key("htmlId"):
-    block += "</%s><!--- /#%s --->" % (d["tag"],d["htmlId"],)
-  else:
-    block += "</%s>" % (d["tag"],)
-
-  return block
+  # return block
 
 
 ## LAST MODIFIED : April 16, 2013
@@ -360,7 +360,7 @@ def searchForm(
         span=2,
         inlineHelpText=False,
         blockHelpText=False,
-        focusedInput=False):
+        focusedInputText=False):
     """Generate a search-form - TBS style
 
     **Key Arguments:**
@@ -433,7 +433,7 @@ def form(
 
     thisList = ["inline", "horizontal", "search"]
     if formType in thisList:
-        formType = """form-%s""" % (item,)
+        formType = """form-%s""" % (i,)
 
     form = """
         <form class="%s">
@@ -520,6 +520,7 @@ def formInput(
         append=False,
         button1=False,
         button2=False,
+        prependDropdown=False,
         appendDropdown=False,
         inlineHelpText=False,
         blockHelpText=False,
@@ -550,6 +551,12 @@ def formInput(
     **Return:**
         - ``input`` -- the input
     """
+    prependContent=False
+    appendContent=False
+    inputId=False
+    searchBar=False
+    searchClass=False
+
     falseList = [searchBar,span,prepend,prependContent,append,appendContent,inputId,pull]
 
     for i in range(len(falseList)):
@@ -564,7 +571,7 @@ def formInput(
     if span:
         span = "span%s" % (span,)
 
-    if searchbar:
+    if searchBar:
         searchClass = "search-query"
 
     if prepend is True:
@@ -622,11 +629,11 @@ def formInput(
     else:
         blockHelpText = ""
 
-    if focusedInputText:
-        focusedInputText = """focusedInputText%s""" % (focusedInputText,)
+    if focusedInput:
+        focusedInput = """focusedInput%s""" % (focusedInput,)
         focusId = "focusedInput"
     else:
-        focusedInputText = ""
+        focusedInput = ""
         focusId = ""
 
     if required:
@@ -647,7 +654,7 @@ def formInput(
             <input class="%s %s" id="%s %s %s" value="%s" type="%s" placeholder="%s" %s %s>
             %s
         </div>%s%s
-        """ % (prepend, append, pull, prependContent, span, searchClass, inputId, focusId, disabledId, focusedInputText, ttype, placeholder, required, disabled, appendContent, inlineHelpText, blockHelpText)
+        """ % (prepend, append, pull, prependContent, span, searchClass, inputId, focusId, disabledId, focusedInput, ttype, placeholder, required, disabled, appendContent, inlineHelpText, blockHelpText)
 
     return formInput
 
@@ -1005,7 +1012,7 @@ def formActions(
     formActions = """
         <div class="form-actions">
           %s
-          %S
+          %s
           %s
           %s
           %s
